module :py:mod:`tarantool.mesh_connection`
==========================================

.. automodule:: tarantool.mesh_connection
   :exclude-members: MeshConnection

   .. autoclass:: tarantool.mesh_connection.MeshConnection
      :exclude-members: Error, DatabaseError, InterfaceError,
         ConfigurationError, SchemaError, NetworkError,
         Warning, DataError, OperationalError, IntegrityError,
         InternalError, ProgrammingError, NotSupportedError

      .. autoattribute:: Error
         :noindex:

      .. autoattribute:: DatabaseError
         :noindex:

      .. autoattribute:: InterfaceError
         :noindex:

      .. autoattribute:: ConfigurationError
         :noindex:

      .. autoattribute:: SchemaError
         :noindex:

      .. autoattribute:: NetworkError
         :noindex:

      .. autoattribute:: Warning
         :noindex:

      .. autoattribute:: DataError
         :noindex:

      .. autoattribute:: OperationalError
         :noindex:

      .. autoattribute:: IntegrityError
         :noindex:

      .. autoattribute:: InternalError
         :noindex:

      .. autoattribute:: ProgrammingError
         :noindex:

      .. autoattribute:: NotSupportedError
         :noindex:
